@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT_OK @EXPORT);
-$VERSION = '0.28';
+$VERSION = '1.00';
 
 #----------------------------------------------------------------------------
 
@@ -343,7 +343,7 @@ sub _setargs {
         
                 # exclude weekdays
                 } elsif(lc $key2 eq 'weekday') {
-                    for $inx (1..5) { $Settings{exclude}{days}->[$inx] = $hash->{$key1}{$key2}; }
+                    for my $index (1..5) { $Settings{exclude}{days}->[$index] = $hash->{$key1}{$key2}; }
         
                 # check for holiday setting
                 } elsif(lc $key2 eq 'holidays' and ref($hash->{$key1}{$key2}) eq 'ARRAY') {
@@ -552,7 +552,7 @@ for testing the beta versions.
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright (C) 2003-2014 Barbie for Miss Barbell Productions
+  Copyright (C) 2003-2019 Barbie for Miss Barbell Productions
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic License v2.
